@@ -170,4 +170,4 @@ if __name__ == "__main__":
     token = "24dc77b46c7542a28cc74888aed16d15fc0d0d3077ed48e5b68956e2668eef27"
     server = STFServer(url='http://10.12.35.2:8086', token=token)
     print(server.get_devices())
-    print(server.find_ios_bundle_id("fbe6152eac9593147e48fb0164efffe164857f0f", "com.yy.net.test"))
+    # print(server.get_devices("fbe6152eac9593147e48fb0164efffe164857f0f", "com.yy.net.test"))
