@@ -1,9 +1,9 @@
 import requests
 import time
+import logging
 from yyweaknet.stf import STFServer
-from yyweaknet.logger import get_logger
 
-logger = get_logger(__name__)
+logger = logging.getLogger("main")
 
 
 class WeakNetworkConfig(object):
@@ -18,7 +18,7 @@ class WeakNetworkConfig(object):
     ATC_AUTH_URI = "/api/v1/auth/{}/"
     ATC_SHAPE_URI = "/api/v1/shape/{}/"
 
-    def __init__(self, atc_host="http://172.29.182.90:8000", stf_url=None, sft_token=None, wifi_name="yy_net",
+    def __init__(self, atc_host="http://172.29.182.152:8000", stf_url=None, sft_token=None, wifi_name="yy_net",
                  wifi_password=""):
         """
             :param atc_host: atc服务地址
@@ -91,6 +91,7 @@ class WeakNetworkConfig(object):
             logger.info("get toggleAndroidWifi response :{}".format(ret))
             ip = ret.get("ip", None)
             if str(ip).startswith("192.168.0"):
+                self.set_auth(ip)
                 return ip
             else:
                 time.sleep(1)
@@ -110,7 +111,7 @@ class WeakNetworkConfig(object):
             if device_ip:
                 # 弱网断网现在是192.168.0 如果网段变化则需要修改下面的逻辑
                 if device_ip.startswith('192.168.0'):
-                    self._set_auth(device_ip)
+                    self.set_auth(device_ip)
                     return device_ip
                 else:
                     time.sleep(1)
@@ -137,10 +138,10 @@ class WeakNetworkConfig(object):
         if device_ip.startswith('192.168.0') is False:
             return True
 
-    def _set_auth(self, device_ip):
+    def set_auth(self, device_ip):
         url = "{host}{uri}".format(host=self._atc_host,
                                    uri=WeakNetworkConfig.ATC_AUTH_URI.format(device_ip))
-        r = requests.post(url)
+        r = requests.post(url, json={"token": 12345})
         logger.info("set_auth response {}".format(r.text))
         try:
             if r.status_code == 200:
@@ -161,7 +162,7 @@ class WeakNetworkConfig(object):
         r = requests.post(url, json=config_json)
         logger.info("set_net_config response {}".format(r.text))
         try:
-            if r.status_code == 200:
+            if r.status_code == 201:
                 return True
             else:
                 return False
@@ -172,5 +173,53 @@ class WeakNetworkConfig(object):
 if __name__ == '__main__':
     token = "24dc77b46c7542a28cc74888aed16d15fc0d0d3077ed48e5b68956e2668eef27"
     sft_url = "http://10.12.35.2:8086"
-    config = WeakNetworkConfig("2834d69c9ee8c9c02280d7d8828697cde1920cd6", stf_url=sft_url, sft_token=token)
-    print(config)
+    config = WeakNetworkConfig(stf_url=sft_url, sft_token=token)
+    json_config = {
+        "up": {
+            "loss": {
+                "percentage": "30",
+                "correlation": 0
+            },
+            "rate": "1024",
+            "delay": {
+                "delay": 0,
+                "jitter": 0,
+                "correlation": 0
+            },
+            "reorder": {
+                "gap": 0,
+                "percentage": 0,
+                "correlation": 0
+            },
+            "corruption": {
+                "percentage": 0,
+                "correlation": 0
+            },
+            "iptables_options": []
+        },
+        "down": {
+            "loss": {
+                "percentage": "30",
+                "correlation": 0
+            },
+            "rate": "1024",
+            "delay": {
+                "delay": 0,
+                "jitter": 0,
+                "correlation": 0
+            },
+            "reorder": {
+                "gap": 0,
+                "percentage": 0,
+                "correlation": 0
+            },
+            "corruption": {
+                "percentage": 0,
+                "correlation": 0
+            },
+            "iptables_options": []
+        }
+    }
+    config.set_auth("192.168.0.11")
+    flag = config.set_net_config("192.168.0.11", json_config)
+    print(flag)
